@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::ClassStartup;
 
-our $DATE = '2016-11-25'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2016-11-26'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -39,7 +39,7 @@ Bencher::Scenario::Accessors::ClassStartup - Benchmark startup of classes using
 
 =head1 VERSION
 
-This document describes version 0.12 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-11-25.
+This document describes version 0.13 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-11-26.
 
 =head1 SYNOPSIS
 
@@ -99,55 +99,55 @@ L<Object::Tiny::RW::XS> 0.03
 
 L<Object::Tiny::XS> 1.01
 
-L<Perl::Examples::Accessors::Array> 0.09
+L<Perl::Examples::Accessors::Array> 0.11
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.09
+L<Perl::Examples::Accessors::ClassAccessor> 0.11
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.09
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.11
 
-L<Perl::Examples::Accessors::ClassInsideOut> 0.09
+L<Perl::Examples::Accessors::ClassInsideOut> 0.11
 
-L<Perl::Examples::Accessors::ClassStruct> 0.09
+L<Perl::Examples::Accessors::ClassStruct> 0.11
 
-L<Perl::Examples::Accessors::ClassTiny> 0.09
+L<Perl::Examples::Accessors::ClassTiny> 0.11
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.09
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.11
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.09
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.11
 
-L<Perl::Examples::Accessors::EvoClass> 0.09
+L<Perl::Examples::Accessors::EvoClass> 0.11
 
-L<Perl::Examples::Accessors::Hash> 0.09
+L<Perl::Examples::Accessors::Hash> 0.11
 
-L<Perl::Examples::Accessors::Mo> 0.09
+L<Perl::Examples::Accessors::Mo> 0.11
 
-L<Perl::Examples::Accessors::MojoBase> 0.09
+L<Perl::Examples::Accessors::MojoBase> 0.11
 
-L<Perl::Examples::Accessors::MojoBaseXS> 0.09
+L<Perl::Examples::Accessors::MojoBaseXS> 0.11
 
-L<Perl::Examples::Accessors::Moo> 0.09
+L<Perl::Examples::Accessors::Moo> 0.11
 
-L<Perl::Examples::Accessors::Moops> 0.09
+L<Perl::Examples::Accessors::Moops> 0.11
 
-L<Perl::Examples::Accessors::Moos> 0.09
+L<Perl::Examples::Accessors::Moos> 0.11
 
-L<Perl::Examples::Accessors::Moose> 0.09
+L<Perl::Examples::Accessors::Moose> 0.11
 
-L<Perl::Examples::Accessors::Mouse> 0.09
+L<Perl::Examples::Accessors::Mouse> 0.11
 
-L<Perl::Examples::Accessors::ObjectSimple> 0.09
+L<Perl::Examples::Accessors::ObjectSimple> 0.11
 
-L<Perl::Examples::Accessors::ObjectTiny> 0.09
+L<Perl::Examples::Accessors::ObjectTiny> 0.11
 
-L<Perl::Examples::Accessors::ObjectTinyRW> 0.09
+L<Perl::Examples::Accessors::ObjectTinyRW> 0.11
 
-L<Perl::Examples::Accessors::ObjectTinyRWXS> 0.09
+L<Perl::Examples::Accessors::ObjectTinyRWXS> 0.11
 
-L<Perl::Examples::Accessors::ObjectTinyXS> 0.09
+L<Perl::Examples::Accessors::ObjectTinyXS> 0.11
 
-L<Perl::Examples::Accessors::Scalar> 0.09
+L<Perl::Examples::Accessors::Scalar> 0.11
 
-L<Perl::Examples::Accessors::SimpleAccessor> 0.09
+L<Perl::Examples::Accessors::SimpleAccessor> 0.11
 
 L<Simple::Accessor> 1.02
 
@@ -155,15 +155,9 @@ L<Simple::Accessor> 1.02
 
 =over
 
-=item * Perl::Examples::Accessors::ClassStruct (perl_code)
+=item * Perl::Examples::Accessors::ObjectTinyXS (perl_code)
 
-L<Perl::Examples::Accessors::ClassStruct>
-
-
-
-=item * Perl::Examples::Accessors::Moo (perl_code)
-
-L<Perl::Examples::Accessors::Moo>
+L<Perl::Examples::Accessors::ObjectTinyXS>
 
 
 
@@ -173,111 +167,33 @@ L<Perl::Examples::Accessors::ObjectTinyRWXS>
 
 
 
+=item * Perl::Examples::Accessors::ClassStruct (perl_code)
+
+L<Perl::Examples::Accessors::ClassStruct>
+
+
+
 =item * Perl::Examples::Accessors::ClassInsideOut (perl_code)
 
 L<Perl::Examples::Accessors::ClassInsideOut>
 
 
 
-=item * Perl::Examples::Accessors::Mouse (perl_code)
-
-L<Perl::Examples::Accessors::Mouse>
-
-
-
-=item * Perl::Examples::Accessors::Moose (perl_code)
-
-L<Perl::Examples::Accessors::Moose>
-
-
-
-=item * Perl::Examples::Accessors::MojoBase (perl_code)
-
-L<Perl::Examples::Accessors::MojoBase>
-
-
-
-=item * Perl::Examples::Accessors::Scalar (perl_code)
-
-L<Perl::Examples::Accessors::Scalar>
-
-
-
 =item * Perl::Examples::Accessors::EvoClass (perl_code)
 
 L<Perl::Examples::Accessors::EvoClass>
 
 
 
-=item * Perl::Examples::Accessors::ClassAccessor (perl_code)
+=item * Perl::Examples::Accessors::Scalar (perl_code)
 
-L<Perl::Examples::Accessors::ClassAccessor>
+L<Perl::Examples::Accessors::Scalar>
 
 
 
-=item * Perl::Examples::Accessors::Mo (perl_code)
+=item * Perl::Examples::Accessors::Moo (perl_code)
 
-L<Perl::Examples::Accessors::Mo>
-
-
-
-=item * Perl::Examples::Accessors::SimpleAccessor (perl_code)
-
-L<Perl::Examples::Accessors::SimpleAccessor>
-
-
-
-=item * Perl::Examples::Accessors::MojoBaseXS (perl_code)
-
-L<Perl::Examples::Accessors::MojoBaseXS>
-
-
-
-=item * Perl::Examples::Accessors::ObjectTinyXS (perl_code)
-
-L<Perl::Examples::Accessors::ObjectTinyXS>
-
-
-
-=item * Perl::Examples::Accessors::ObjectSimple (perl_code)
-
-L<Perl::Examples::Accessors::ObjectSimple>
-
-
-
-=item * Perl::Examples::Accessors::Moos (perl_code)
-
-L<Perl::Examples::Accessors::Moos>
-
-
-
-=item * Perl::Examples::Accessors::ClassXSAccessor (perl_code)
-
-L<Perl::Examples::Accessors::ClassXSAccessor>
-
-
-
-=item * Perl::Examples::Accessors::ClassTiny (perl_code)
-
-L<Perl::Examples::Accessors::ClassTiny>
-
-
-
-=item * Perl::Examples::Accessors::Moops (perl_code)
-
-L<Perl::Examples::Accessors::Moops>
-
-
-
-=item * Perl::Examples::Accessors::ClassAccessorArray (perl_code)
-
-L<Perl::Examples::Accessors::ClassAccessorArray>
-
-
-
-=item * Perl::Examples::Accessors::Array (perl_code)
-
-L<Perl::Examples::Accessors::Array>
+L<Perl::Examples::Accessors::Moo>
 
 
 
@@ -287,21 +203,105 @@ L<Perl::Examples::Accessors::ClassXSAccessorArray>
 
 
 
+=item * Perl::Examples::Accessors::ClassXSAccessor (perl_code)
+
+L<Perl::Examples::Accessors::ClassXSAccessor>
+
+
+
 =item * Perl::Examples::Accessors::ObjectTinyRW (perl_code)
 
 L<Perl::Examples::Accessors::ObjectTinyRW>
 
 
 
+=item * Perl::Examples::Accessors::MojoBaseXS (perl_code)
+
+L<Perl::Examples::Accessors::MojoBaseXS>
+
+
+
+=item * Perl::Examples::Accessors::Moos (perl_code)
+
+L<Perl::Examples::Accessors::Moos>
+
+
+
+=item * Perl::Examples::Accessors::ClassAccessorArray (perl_code)
+
+L<Perl::Examples::Accessors::ClassAccessorArray>
+
+
+
+=item * Perl::Examples::Accessors::ClassAccessor (perl_code)
+
+L<Perl::Examples::Accessors::ClassAccessor>
+
+
+
+=item * Perl::Examples::Accessors::SimpleAccessor (perl_code)
+
+L<Perl::Examples::Accessors::SimpleAccessor>
+
+
+
+=item * Perl::Examples::Accessors::Mouse (perl_code)
+
+L<Perl::Examples::Accessors::Mouse>
+
+
+
+=item * Perl::Examples::Accessors::Mo (perl_code)
+
+L<Perl::Examples::Accessors::Mo>
+
+
+
+=item * Perl::Examples::Accessors::Moose (perl_code)
+
+L<Perl::Examples::Accessors::Moose>
+
+
+
+=item * Perl::Examples::Accessors::Array (perl_code)
+
+L<Perl::Examples::Accessors::Array>
+
+
+
+=item * Perl::Examples::Accessors::MojoBase (perl_code)
+
+L<Perl::Examples::Accessors::MojoBase>
+
+
+
+=item * Perl::Examples::Accessors::ObjectTiny (perl_code)
+
+L<Perl::Examples::Accessors::ObjectTiny>
+
+
+
+=item * Perl::Examples::Accessors::Moops (perl_code)
+
+L<Perl::Examples::Accessors::Moops>
+
+
+
+=item * Perl::Examples::Accessors::ObjectSimple (perl_code)
+
+L<Perl::Examples::Accessors::ObjectSimple>
+
+
+
 =item * Perl::Examples::Accessors::Hash (perl_code)
 
 L<Perl::Examples::Accessors::Hash>
 
 
 
-=item * Perl::Examples::Accessors::ObjectTiny (perl_code)
+=item * Perl::Examples::Accessors::ClassTiny (perl_code)
 
-L<Perl::Examples::Accessors::ObjectTiny>
+L<Perl::Examples::Accessors::ClassTiny>
 
 
 
@@ -317,32 +317,32 @@ Benchmark with default options (C<< bencher -m Accessors::ClassStartup >>):
  +-------------------------------------------------+-----------+------------------------+------------+-----------+---------+
  | participant                                     | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
  +-------------------------------------------------+-----------+------------------------+------------+-----------+---------+
- | Perl::Examples::Accessors::Moops                |    160    |    154.4               |       1    |   0.00016 |      20 |
- | Perl::Examples::Accessors::Moose                |    150    |    144.4               |       1.1  |   0.00016 |      20 |
- | Perl::Examples::Accessors::EvoClass             |     36    |     30.4               |       4.5  | 8.5e-05   |      20 |
- | Perl::Examples::Accessors::Moo                  |     30    |     24.4               |       5.4  | 4.6e-05   |      20 |
- | Perl::Examples::Accessors::Mouse                |     24.2  |     18.6               |       6.75 | 1.1e-05   |      20 |
- | Perl::Examples::Accessors::Moos                 |     21    |     15.4               |       7.9  | 5.4e-05   |      20 |
- | Perl::Examples::Accessors::ClassInsideOut       |     16.3  |     10.7               |      10.1  | 1.5e-05   |      20 |
- | Perl::Examples::Accessors::MojoBase             |     16    |     10.4               |      10    | 5.2e-05   |      20 |
- | Perl::Examples::Accessors::ClassTiny            |     14    |      8.4               |      11    | 3.1e-05   |      20 |
- | Perl::Examples::Accessors::ClassStruct          |     13    |      7.4               |      12    | 4.7e-05   |      21 |
- | Perl::Examples::Accessors::ObjectSimple         |     13    |      7.4               |      13    | 2.1e-05   |      20 |
- | Perl::Examples::Accessors::ClassXSAccessorArray |     13    |      7.4               |      13    | 3.4e-05   |      20 |
- | Perl::Examples::Accessors::ObjectTinyXS         |     12    |      6.4               |      13    | 1.3e-05   |      20 |
- | Perl::Examples::Accessors::ObjectTinyRWXS       |     12    |      6.4               |      13    | 1.3e-05   |      20 |
- | Perl::Examples::Accessors::ClassAccessor        |     12    |      6.4               |      13    | 1.7e-05   |      21 |
- | Perl::Examples::Accessors::ClassXSAccessor      |     12    |      6.4               |      13    | 1.5e-05   |      20 |
- | Perl::Examples::Accessors::MojoBaseXS           |      9.25 |      3.65              |      17.7  | 7.8e-06   |      20 |
- | Perl::Examples::Accessors::SimpleAccessor       |      8.4  |      2.8               |      19    | 3.9e-05   |      20 |
- | Perl::Examples::Accessors::Mo                   |      8.1  |      2.5               |      20    | 1.9e-05   |      20 |
- | Perl::Examples::Accessors::ClassAccessorArray   |      7.9  |      2.3               |      21    | 2.2e-05   |      21 |
- | Perl::Examples::Accessors::ObjectTiny           |      6.9  |      1.3               |      24    | 1.9e-05   |      22 |
- | Perl::Examples::Accessors::ObjectTinyRW         |      6.9  |      1.3               |      24    | 4.4e-05   |      20 |
- | Perl::Examples::Accessors::Scalar               |      6.2  |      0.600000000000001 |      26    | 2.5e-05   |      20 |
- | Perl::Examples::Accessors::Array                |      6    |      0.4               |      27    | 2.3e-05   |      20 |
- | Perl::Examples::Accessors::Hash                 |      6    |      0.4               |      27    | 7.4e-06   |      21 |
- | perl -e1 (baseline)                             |      5.6  |      0                 |      29    | 1.7e-05   |      20 |
+ | Perl::Examples::Accessors::Moops                |     200   |                  193.4 |        1   |   0.0039  |      20 |
+ | Perl::Examples::Accessors::Moose                |     210   |                  203.4 |        1.1 |   0.0014  |      20 |
+ | Perl::Examples::Accessors::Moo                  |      70   |                   63.4 |        3   |   0.0029  |      20 |
+ | Perl::Examples::Accessors::EvoClass             |      60   |                   53.4 |        4   |   0.0021  |      21 |
+ | Perl::Examples::Accessors::Mouse                |      40   |                   33.4 |        6   |   0.00053 |      20 |
+ | Perl::Examples::Accessors::Moos                 |      30   |                   23.4 |        8   |   0.00062 |      22 |
+ | Perl::Examples::Accessors::ClassXSAccessorArray |      30   |                   23.4 |        9   |   0.00091 |      20 |
+ | Perl::Examples::Accessors::MojoBase             |      20   |                   13.4 |       10   |   0.00043 |      22 |
+ | Perl::Examples::Accessors::ClassAccessor        |      20   |                   13.4 |       10   |   0.00056 |      20 |
+ | Perl::Examples::Accessors::ClassInsideOut       |      21   |                   14.4 |       12   | 4.9e-05   |      22 |
+ | Perl::Examples::Accessors::ClassTiny            |      18   |                   11.4 |       13   |   5e-05   |      20 |
+ | Perl::Examples::Accessors::ClassXSAccessor      |      20   |                   13.4 |       10   |   0.00025 |      20 |
+ | Perl::Examples::Accessors::ClassStruct          |      17   |                   10.4 |       14   | 7.5e-05   |      20 |
+ | Perl::Examples::Accessors::ObjectSimple         |      16   |                    9.4 |       15   | 8.2e-05   |      20 |
+ | Perl::Examples::Accessors::ObjectTinyRWXS       |      15   |                    8.4 |       15   |   8e-05   |      20 |
+ | Perl::Examples::Accessors::ObjectTinyXS         |      15   |                    8.4 |       16   | 1.6e-05   |      20 |
+ | Perl::Examples::Accessors::SimpleAccessor       |      10   |                    3.4 |       20   |   0.0004  |      21 |
+ | Perl::Examples::Accessors::ObjectTiny           |      10   |                    3.4 |       20   |   0.00035 |      21 |
+ | Perl::Examples::Accessors::MojoBaseXS           |      11   |                    4.4 |       22   | 1.3e-05   |      20 |
+ | Perl::Examples::Accessors::ClassAccessorArray   |      10   |                    3.4 |       24   | 6.7e-05   |      20 |
+ | Perl::Examples::Accessors::Mo                   |       9.7 |                    3.1 |       24   | 4.7e-05   |      20 |
+ | Perl::Examples::Accessors::Scalar               |       9   |                    2.4 |       30   |   0.0002  |      20 |
+ | Perl::Examples::Accessors::ObjectTinyRW         |       7.9 |                    1.3 |       30   | 1.4e-05   |      20 |
+ | Perl::Examples::Accessors::Array                |       7.5 |                    0.9 |       32   | 3.5e-05   |      20 |
+ | Perl::Examples::Accessors::Hash                 |       7   |                    0.4 |       34   | 1.2e-05   |      21 |
+ | perl -e1 (baseline)                             |       6.6 |                    0   |       36   | 1.3e-05   |      20 |
  +-------------------------------------------------+-----------+------------------------+------------+-----------+---------+
 
 =head1 HOMEPAGE
