@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Construction;
 
-our $DATE = '2016-11-25'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2016-11-26'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -46,7 +46,7 @@ Bencher::Scenario::Accessors::Construction - Benchmark object construction
 
 =head1 VERSION
 
-This document describes version 0.12 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-11-25.
+This document describes version 0.13 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-11-26.
 
 =head1 SYNOPSIS
 
@@ -110,57 +110,57 @@ L<Object::Tiny::RW::XS> 0.03
 
 L<Object::Tiny::XS> 1.01
 
-L<Perl::Examples::Accessors> 0.09
+L<Perl::Examples::Accessors> 0.11
 
-L<Perl::Examples::Accessors::Array> 0.09
+L<Perl::Examples::Accessors::Array> 0.11
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.09
+L<Perl::Examples::Accessors::ClassAccessor> 0.11
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.09
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.11
 
-L<Perl::Examples::Accessors::ClassInsideOut> 0.09
+L<Perl::Examples::Accessors::ClassInsideOut> 0.11
 
-L<Perl::Examples::Accessors::ClassStruct> 0.09
+L<Perl::Examples::Accessors::ClassStruct> 0.11
 
-L<Perl::Examples::Accessors::ClassTiny> 0.09
+L<Perl::Examples::Accessors::ClassTiny> 0.11
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.09
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.11
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.09
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.11
 
-L<Perl::Examples::Accessors::EvoClass> 0.09
+L<Perl::Examples::Accessors::EvoClass> 0.11
 
-L<Perl::Examples::Accessors::Hash> 0.09
+L<Perl::Examples::Accessors::Hash> 0.11
 
-L<Perl::Examples::Accessors::Mo> 0.09
+L<Perl::Examples::Accessors::Mo> 0.11
 
-L<Perl::Examples::Accessors::MojoBase> 0.09
+L<Perl::Examples::Accessors::MojoBase> 0.11
 
-L<Perl::Examples::Accessors::MojoBaseXS> 0.09
+L<Perl::Examples::Accessors::MojoBaseXS> 0.11
 
-L<Perl::Examples::Accessors::Moo> 0.09
+L<Perl::Examples::Accessors::Moo> 0.11
 
-L<Perl::Examples::Accessors::Moops> 0.09
+L<Perl::Examples::Accessors::Moops> 0.11
 
-L<Perl::Examples::Accessors::Moos> 0.09
+L<Perl::Examples::Accessors::Moos> 0.11
 
-L<Perl::Examples::Accessors::Moose> 0.09
+L<Perl::Examples::Accessors::Moose> 0.11
 
-L<Perl::Examples::Accessors::Mouse> 0.09
+L<Perl::Examples::Accessors::Mouse> 0.11
 
-L<Perl::Examples::Accessors::ObjectSimple> 0.09
+L<Perl::Examples::Accessors::ObjectSimple> 0.11
 
-L<Perl::Examples::Accessors::ObjectTiny> 0.09
+L<Perl::Examples::Accessors::ObjectTiny> 0.11
 
-L<Perl::Examples::Accessors::ObjectTinyRW> 0.09
+L<Perl::Examples::Accessors::ObjectTinyRW> 0.11
 
-L<Perl::Examples::Accessors::ObjectTinyRWXS> 0.09
+L<Perl::Examples::Accessors::ObjectTinyRWXS> 0.11
 
-L<Perl::Examples::Accessors::ObjectTinyXS> 0.09
+L<Perl::Examples::Accessors::ObjectTinyXS> 0.11
 
-L<Perl::Examples::Accessors::Scalar> 0.09
+L<Perl::Examples::Accessors::Scalar> 0.11
 
-L<Perl::Examples::Accessors::SimpleAccessor> 0.09
+L<Perl::Examples::Accessors::SimpleAccessor> 0.11
 
 L<Simple::Accessor> 1.02
 
@@ -168,19 +168,11 @@ L<Simple::Accessor> 1.02
 
 =over
 
-=item * Class::Struct (perl_code)
+=item * Object::Tiny::XS (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::ClassStruct->new
-
-
-
-=item * Moo (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Moo->new
+ Perl::Examples::Accessors::ObjectTinyXS->new
 
 
 
@@ -192,6 +184,14 @@ Code template:
 
 
 
+=item * Class::Struct (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassStruct->new
+
+
+
 =item * Class::InsideOut (perl_code)
 
 Code template:
@@ -200,38 +200,6 @@ Code template:
 
 
 
-=item * Mouse (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Mouse->new
-
-
-
-=item * Moose (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Moose->new
-
-
-
-=item * Mojo::Base (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::MojoBase->new
-
-
-
-=item * no generator (scalar-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Scalar->new
-
-
-
 =item * Evo::Class (perl_code)
 
 Code template:
@@ -240,99 +208,19 @@ Code template:
 
 
 
-=item * Class::Accessor (perl_code)
+=item * no generator (scalar-based) (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::ClassAccessor->new
+ Perl::Examples::Accessors::Scalar->new
 
 
 
-=item * Mo (perl_code)
+=item * Moo (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::Mo->new
-
-
-
-=item * Simple::Accessor (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::SimpleAccessor->new
-
-
-
-=item * Mojo::Base::XS (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::MojoBaseXS->new
-
-
-
-=item * Object::Tiny::XS (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ObjectTinyXS->new
-
-
-
-=item * Object::Simple (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ObjectSimple->new
-
-
-
-=item * Moos (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Moos->new
-
-
-
-=item * Class::XSAccessor (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassXSAccessor->new
-
-
-
-=item * Class::Tiny (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassTiny->new
-
-
-
-=item * Moops (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Moops->new
-
-
-
-=item * Class::Accessor::Array (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassAccessorArray->new
-
-
-
-=item * no generator (array-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Array->new
+ Perl::Examples::Accessors::Moo->new
 
 
 
@@ -344,6 +232,14 @@ Code template:
 
 
 
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassXSAccessor->new
+
+
+
 =item * Object::Tiny::RW (perl_code)
 
 Code template:
@@ -352,6 +248,110 @@ Code template:
 
 
 
+=item * Mojo::Base::XS (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::MojoBaseXS->new
+
+
+
+=item * Moos (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Moos->new
+
+
+
+=item * Class::Accessor::Array (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassAccessorArray->new
+
+
+
+=item * Class::Accessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassAccessor->new
+
+
+
+=item * Simple::Accessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::SimpleAccessor->new
+
+
+
+=item * Mouse (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Mouse->new
+
+
+
+=item * Mo (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Mo->new
+
+
+
+=item * Moose (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Moose->new
+
+
+
+=item * no generator (array-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Array->new
+
+
+
+=item * Mojo::Base (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::MojoBase->new
+
+
+
+=item * Object::Tiny (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ObjectTiny->new
+
+
+
+=item * Moops (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Moops->new
+
+
+
+=item * Object::Simple (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ObjectSimple->new
+
+
+
 =item * no generator (hash-based) (perl_code)
 
 Code template:
@@ -360,11 +360,11 @@ Code template:
 
 
 
-=item * Object::Tiny (perl_code)
+=item * Class::Tiny (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::ObjectTiny->new
+ Perl::Examples::Accessors::ClassTiny->new
 
 
 
@@ -380,31 +380,31 @@ Benchmark with default options (C<< bencher -m Accessors::Construction >>):
  +-----------------------------+-----------+-----------+------------+---------+---------+
  | participant                 | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +-----------------------------+-----------+-----------+------------+---------+---------+
- | Moos                        |    141000 |  7.12     |    1       | 3.3e-09 |      20 |
- | Class::InsideOut            |    330000 |  3        |    2.4     | 3.8e-09 |      24 |
- | Simple::Accessor            |    450000 |  2.22     |    3.2     | 6.8e-10 |      30 |
- | Class::Tiny                 |    645176 |  1.54996  |    4.59165 |   0     |      22 |
- | Evo::Class                  |    814000 |  1.23     |    5.79    | 4.2e-10 |      20 |
- | Moose                       |    825000 |  1.21     |    5.87    | 3.8e-10 |      24 |
- | Mo                          |   1070000 |  0.932    |    7.64    | 4.2e-10 |      20 |
- | Class::Struct               |   1212000 |  0.8251   |    8.625   | 1.2e-11 |      27 |
- | Moops                       |   1300000 |  0.76     |    9.4     | 1.6e-09 |      21 |
- | Moo                         |   1320000 |  0.757    |    9.4     | 4.2e-10 |      20 |
- | Class::Accessor             |   1546430 |  0.646649 |   11.0058  |   0     |      20 |
- | Mouse                       |   1703000 |  0.5872   |   12.12    | 3.4e-11 |      20 |
- | no generator (array-based)  |   2100000 |  0.48     |   15       | 5.6e-10 |      25 |
- | no generator (hash-based)   |   2550410 |  0.392094 |   18.151   |   0     |      20 |
- | Mojo::Base                  |   2700000 |  0.371    |   19.2     | 2.1e-10 |      20 |
- | Object::Simple              |   2700000 |  0.37     |   19.2     |   2e-10 |      22 |
- | Object::Tiny::RW            |   2771870 |  0.360768 |   19.7271  |   0     |      20 |
- | Object::Tiny                |   2820000 |  0.355    |   20.1     | 1.8e-10 |      26 |
- | no generator (scalar-based) |   2934000 |  0.3409   |   20.88    | 1.2e-11 |      20 |
- | Class::Accessor::Array      |   2950000 |  0.339    |   21       |   2e-10 |      22 |
- | Object::Tiny::RW::XS        |   4300000 |  0.23     |   30       | 4.2e-10 |      20 |
- | Class::XSAccessor           |   4400000 |  0.23     |   31       | 2.8e-10 |      25 |
- | Mojo::Base::XS              |   4400000 |  0.23     |   31       | 4.2e-10 |      20 |
- | Class::XSAccessor::Array    |   4382620 |  0.228174 |   31.1906  |   0     |      20 |
- | Object::Tiny::XS            |   4388670 |  0.22786  |   31.2336  |   0     |      20 |
+ | Moos                        |     87000 | 12        |     1      | 4.3e-08 |      20 |
+ | Class::InsideOut            |    200000 |  4.9      |     2.4    | 8.1e-09 |      21 |
+ | Simple::Accessor            |    280000 |  3.5      |     3.3    | 6.1e-09 |      24 |
+ | Class::Tiny                 |    384000 |  2.6      |     4.43   | 8.3e-10 |      20 |
+ | Moose                       |    470000 |  2.1      |     5.4    | 7.3e-09 |      21 |
+ | Evo::Class                  |    513000 |  1.95     |     5.92   | 7.3e-10 |      26 |
+ | Mo                          |    620000 |  1.6      |     7.2    | 3.3e-09 |      20 |
+ | Class::Struct               |    720000 |  1.4      |     8.3    | 1.8e-09 |      28 |
+ | Moops                       |    760000 |  1.3      |     8.8    | 1.5e-09 |      24 |
+ | Moo                         |    817000 |  1.22     |     9.42   | 3.8e-10 |      24 |
+ | Class::Accessor             |    942248 |  1.06129  |    10.8673 |   0     |      20 |
+ | Mouse                       |    950000 |  1.1      |    11      | 3.8e-09 |      20 |
+ | no generator (array-based)  |   1200000 |  0.83     |    14      | 2.1e-09 |      20 |
+ | Object::Simple              |   1400000 |  0.72     |    16      | 1.7e-09 |      20 |
+ | no generator (hash-based)   |   1400000 |  0.7      |    16      | 1.7e-09 |      20 |
+ | Mojo::Base                  |   1400000 |  0.7      |    17      | 2.7e-09 |      20 |
+ | Object::Tiny                |   1500000 |  0.67     |    17      | 1.7e-09 |      20 |
+ | Class::Accessor::Array      |   1700000 |  0.6      |    19      |   1e-09 |      20 |
+ | no generator (scalar-based) |   1790000 |  0.56     |    20.6    | 1.8e-10 |      28 |
+ | Object::Tiny::RW            |   1800000 |  0.54     |    21      | 6.4e-10 |      23 |
+ | Object::Tiny::RW::XS        |   2000000 |  0.5      |    20      | 1.6e-08 |      23 |
+ | Object::Tiny::XS            |   2600000 |  0.39     |    30      |   1e-09 |      20 |
+ | Class::XSAccessor::Array    |   2700000 |  0.37     |    31      | 2.9e-09 |      27 |
+ | Class::XSAccessor           |   2800000 |  0.36     |    32      | 3.8e-10 |      20 |
+ | Mojo::Base::XS              |   2846250 |  0.351339 |    32.8269 |   0     |      20 |
  +-----------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 HOMEPAGE
