@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::GeneratorStartup;
 
-our $DATE = '2016-11-25'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2016-11-26'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -35,7 +35,7 @@ Bencher::Scenario::Accessors::GeneratorStartup - Benchmark startup of various ac
 
 =head1 VERSION
 
-This document describes version 0.12 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-11-25.
+This document describes version 0.13 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-11-26.
 
 =head1 SYNOPSIS
 
@@ -101,15 +101,9 @@ L<Simple::Accessor> 1.02
 
 =over
 
-=item * Class::Struct (perl_code)
+=item * Object::Tiny::XS (perl_code)
 
-L<Class::Struct>
-
-
-
-=item * Moo (perl_code)
-
-L<Moo>
+L<Object::Tiny::XS>
 
 
 
@@ -119,132 +113,138 @@ L<Object::Tiny::RW::XS>
 
 
 
+=item * Class::Struct (perl_code)
+
+L<Class::Struct>
+
+
+
 =item * Class::InsideOut (perl_code)
 
 L<Class::InsideOut>
 
 
 
-=item * Mouse (perl_code)
-
-L<Mouse>
-
-
-
-=item * Moose (perl_code)
-
-L<Moose>
-
-
-
-=item * Mojo::Base (perl_code)
-
-L<Mojo::Base>
-
-
-
-=item *  (perl_code)
-
-
-
 =item * Evo::Class (perl_code)
 
 L<Evo::Class>
 
 
 
-=item * Class::Accessor (perl_code)
-
-L<Class::Accessor>
-
-
-
-=item * Mo (perl_code)
-
-L<Mo>
-
-
-
-=item * Simple::Accessor (perl_code)
-
-L<Simple::Accessor>
-
-
-
-=item * Mojo::Base::XS (perl_code)
-
-L<Mojo::Base::XS>
-
-
-
-=item * Object::Tiny::XS (perl_code)
-
-L<Object::Tiny::XS>
-
-
-
-=item * Object::Simple (perl_code)
-
-L<Object::Simple>
-
-
-
-=item * Moos (perl_code)
-
-L<Moos>
-
-
-
-=item * Class::XSAccessor (perl_code)
-
-L<Class::XSAccessor>
-
-
-
-=item * Class::Tiny (perl_code)
-
-L<Class::Tiny>
-
-
-
-=item * Moops (perl_code)
-
-L<Moops>
-
-
-
-=item * Class::Accessor::Array (perl_code)
-
-L<Class::Accessor::Array>
-
-
-
 =item *  (perl_code)
 
 
 
+=item * Moo (perl_code)
+
+L<Moo>
+
+
+
 =item * Class::XSAccessor::Array (perl_code)
 
 L<Class::XSAccessor::Array>
 
 
 
+=item * Class::XSAccessor (perl_code)
+
+L<Class::XSAccessor>
+
+
+
 =item * Object::Tiny::RW (perl_code)
 
 L<Object::Tiny::RW>
 
 
 
+=item * Mojo::Base::XS (perl_code)
+
+L<Mojo::Base::XS>
+
+
+
+=item * Moos (perl_code)
+
+L<Moos>
+
+
+
+=item * Class::Accessor::Array (perl_code)
+
+L<Class::Accessor::Array>
+
+
+
+=item * Class::Accessor (perl_code)
+
+L<Class::Accessor>
+
+
+
+=item * Simple::Accessor (perl_code)
+
+L<Simple::Accessor>
+
+
+
+=item * Mouse (perl_code)
+
+L<Mouse>
+
+
+
+=item * Mo (perl_code)
+
+L<Mo>
+
+
+
+=item * Moose (perl_code)
+
+L<Moose>
+
+
+
 =item *  (perl_code)
 
 
 
+=item * Mojo::Base (perl_code)
+
+L<Mojo::Base>
+
+
+
 =item * Object::Tiny (perl_code)
 
 L<Object::Tiny>
 
 
 
+=item * Moops (perl_code)
+
+L<Moops>
+
+
+
+=item * Object::Simple (perl_code)
+
+L<Object::Simple>
+
+
+
+=item *  (perl_code)
+
+
+
+=item * Class::Tiny (perl_code)
+
+L<Class::Tiny>
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
@@ -257,29 +257,29 @@ Benchmark with default options (C<< bencher -m Accessors::GeneratorStartup >>):
  +--------------------------+-----------+------------------------+------------+-----------+---------+
  | participant              | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
  +--------------------------+-----------+------------------------+------------+-----------+---------+
- | Moose                    |     150   |                  144.3 |        1   |   0.00036 |      20 |
- | Moops                    |      66   |                   60.3 |        2.2 | 6.9e-05   |      20 |
- | Evo::Class               |      36   |                   30.3 |        4.1 |   0.0001  |      21 |
- | Mouse                    |      24   |                   18.3 |        6.1 | 3.5e-05   |      20 |
- | Moos                     |      20   |                   14.3 |        7.3 | 6.3e-05   |      20 |
- | Moo                      |      20   |                   14.3 |        7.6 | 4.4e-05   |      20 |
- | Class::InsideOut         |      16   |                   10.3 |        9.2 | 2.8e-05   |      21 |
- | Mojo::Base               |      16   |                   10.3 |        9.4 | 3.1e-05   |      20 |
- | Class::Tiny              |      14   |                    8.3 |       10   | 3.8e-05   |      20 |
- | Class::Struct            |      13   |                    7.3 |       11   | 3.2e-05   |      21 |
- | Class::XSAccessor::Array |      13   |                    7.3 |       12   | 4.3e-05   |      21 |
- | Object::Tiny::RW::XS     |      13   |                    7.3 |       12   | 3.8e-05   |      20 |
- | Object::Simple           |      13   |                    7.3 |       12   | 1.5e-05   |      21 |
- | Object::Tiny::XS         |      13   |                    7.3 |       12   | 4.6e-05   |      21 |
- | Class::Accessor          |      12   |                    6.3 |       12   | 3.4e-05   |      20 |
- | Class::XSAccessor        |      12   |                    6.3 |       12   |   2e-05   |      20 |
- | Mojo::Base::XS           |       9.5 |                    3.8 |       16   | 5.3e-05   |      20 |
- | Simple::Accessor         |       8.6 |                    2.9 |       17   | 1.7e-05   |      20 |
- | Class::Accessor::Array   |       7.9 |                    2.2 |       19   | 3.2e-05   |      20 |
- | Mo                       |       7.9 |                    2.2 |       19   | 1.1e-05   |      20 |
- | Object::Tiny             |       6.9 |                    1.2 |       21   | 3.5e-05   |      23 |
- | Object::Tiny::RW         |       6.8 |                    1.1 |       22   | 2.1e-05   |      20 |
- | perl -e1 (baseline)      |       5.7 |                    0   |       26   | 1.7e-05   |      20 |
+ | Moose                    |     200   |    191                 |        1   |   0.0008  |      20 |
+ | Moops                    |      85   |     76                 |        2.3 |   0.00019 |      20 |
+ | Evo::Class               |      45   |     36                 |        4.3 |   0.00019 |      20 |
+ | Mouse                    |      32   |     23                 |        6.1 |   0.00018 |      20 |
+ | Moo                      |      30   |     21                 |        7   |   0.00058 |      23 |
+ | Moos                     |      27   |     18                 |        7.3 |   0.00023 |      20 |
+ | Mojo::Base               |      22   |     13                 |        8.8 |   0.00012 |      20 |
+ | Class::XSAccessor        |      20   |     11                 |        9   |   0.00033 |      20 |
+ | Object::Tiny::RW::XS     |      20   |     11                 |        9   |   0.00064 |      22 |
+ | Object::Tiny::XS         |      20   |     11                 |        9   |   0.00085 |      20 |
+ | Class::InsideOut         |      20   |     11                 |        9.8 | 3.7e-05   |      22 |
+ | Class::XSAccessor::Array |      20   |     11                 |       10   |   0.00026 |      20 |
+ | Class::Tiny              |      17   |      8                 |       11   | 3.3e-05   |      20 |
+ | Class::Struct            |      15   |      6                 |       13   |   3e-05   |      20 |
+ | Class::Accessor          |      15   |      6                 |       13   | 4.5e-05   |      20 |
+ | Object::Simple           |      14.9 |      5.9               |       13.1 | 1.3e-05   |      20 |
+ | Mojo::Base::XS           |      12   |      3                 |       16   | 9.9e-05   |      20 |
+ | Simple::Accessor         |      10   |      1                 |       19   | 3.1e-05   |      20 |
+ | Class::Accessor::Array   |       9.7 |      0.699999999999999 |       20   | 2.1e-05   |      20 |
+ | Mo                       |       9.3 |      0.300000000000001 |       21   | 2.1e-05   |      21 |
+ | perl -e1 (baseline)      |       9   |      0                 |       20   |   0.00016 |      22 |
+ | Object::Tiny::RW         |       8   |     -1                 |       24   | 3.1e-05   |      20 |
+ | Object::Tiny             |       7.9 |     -1.1               |       25   | 9.1e-06   |      20 |
  +--------------------------+-----------+------------------------+------------+-----------+---------+
 
 =head1 HOMEPAGE
