@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::Accessors::ClassStartup;
 
-our $VERSION = 0.12; # VERSION
+our $VERSION = 0.13; # VERSION
 
 our $results = [
   [
@@ -8,212 +8,212 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.00016,
-        mod_overhead_time => 154.4,
+        errors => 0.0039,
+        mod_overhead_time => 193.4,
         participant => "Perl::Examples::Accessors::Moops",
         samples => 20,
-        time => 160,
+        time => 200,
         vs_slowest => 1,
       },
       {
-        errors => 0.00016,
-        mod_overhead_time => 144.4,
+        errors => 0.0014,
+        mod_overhead_time => 203.4,
         participant => "Perl::Examples::Accessors::Moose",
         samples => 20,
-        time => 150,
+        time => 210,
         vs_slowest => 1.1,
       },
       {
-        errors => 8.5e-05,
-        mod_overhead_time => 30.4,
-        participant => "Perl::Examples::Accessors::EvoClass",
-        samples => 20,
-        time => 36,
-        vs_slowest => 4.5,
-      },
-      {
-        errors => 4.6e-05,
-        mod_overhead_time => 24.4,
+        errors => 0.0029,
+        mod_overhead_time => 63.4,
         participant => "Perl::Examples::Accessors::Moo",
         samples => 20,
-        time => 30,
-        vs_slowest => 5.4,
+        time => 70,
+        vs_slowest => 3,
       },
       {
-        errors => 1.1e-05,
-        mod_overhead_time => 18.6,
+        errors => 0.0021,
+        mod_overhead_time => 53.4,
+        participant => "Perl::Examples::Accessors::EvoClass",
+        samples => 21,
+        time => 60,
+        vs_slowest => 4,
+      },
+      {
+        errors => 0.00053,
+        mod_overhead_time => 33.4,
         participant => "Perl::Examples::Accessors::Mouse",
         samples => 20,
-        time => 24.2,
-        vs_slowest => 6.75,
+        time => 40,
+        vs_slowest => 6,
       },
       {
-        errors => 5.4e-05,
-        mod_overhead_time => 15.4,
+        errors => 0.00062,
+        mod_overhead_time => 23.4,
         participant => "Perl::Examples::Accessors::Moos",
-        samples => 20,
-        time => 21,
-        vs_slowest => 7.9,
+        samples => 22,
+        time => 30,
+        vs_slowest => 8,
       },
       {
-        errors => 1.5e-05,
-        mod_overhead_time => 10.7,
-        participant => "Perl::Examples::Accessors::ClassInsideOut",
+        errors => 0.00091,
+        mod_overhead_time => 23.4,
+        participant => "Perl::Examples::Accessors::ClassXSAccessorArray",
         samples => 20,
-        time => 16.3,
-        vs_slowest => 10.1,
+        time => 30,
+        vs_slowest => 9,
       },
       {
-        errors => 5.2e-05,
-        mod_overhead_time => 10.4,
+        errors => 0.00043,
+        mod_overhead_time => 13.4,
         participant => "Perl::Examples::Accessors::MojoBase",
-        samples => 20,
-        time => 16,
+        samples => 22,
+        time => 20,
         vs_slowest => 10,
       },
       {
-        errors => 3.1e-05,
-        mod_overhead_time => 8.4,
-        participant => "Perl::Examples::Accessors::ClassTiny",
+        errors => 0.00056,
+        mod_overhead_time => 13.4,
+        participant => "Perl::Examples::Accessors::ClassAccessor",
         samples => 20,
-        time => 14,
-        vs_slowest => 11,
+        time => 20,
+        vs_slowest => 10,
       },
       {
-        errors => 4.7e-05,
-        mod_overhead_time => 7.4,
-        participant => "Perl::Examples::Accessors::ClassStruct",
-        samples => 21,
-        time => 13,
+        errors => 4.9e-05,
+        mod_overhead_time => 14.4,
+        participant => "Perl::Examples::Accessors::ClassInsideOut",
+        samples => 22,
+        time => 21,
         vs_slowest => 12,
       },
       {
-        errors => 2.1e-05,
-        mod_overhead_time => 7.4,
-        participant => "Perl::Examples::Accessors::ObjectSimple",
+        errors => 5e-05,
+        mod_overhead_time => 11.4,
+        participant => "Perl::Examples::Accessors::ClassTiny",
         samples => 20,
-        time => 13,
+        time => 18,
         vs_slowest => 13,
       },
       {
-        errors => 3.4e-05,
-        mod_overhead_time => 7.4,
-        participant => "Perl::Examples::Accessors::ClassXSAccessorArray",
-        samples => 20,
-        time => 13,
-        vs_slowest => 13,
-      },
-      {
-        errors => 1.3e-05,
-        mod_overhead_time => 6.4,
-        participant => "Perl::Examples::Accessors::ObjectTinyXS",
-        samples => 20,
-        time => 12,
-        vs_slowest => 13,
-      },
-      {
-        errors => 1.3e-05,
-        mod_overhead_time => 6.4,
-        participant => "Perl::Examples::Accessors::ObjectTinyRWXS",
-        samples => 20,
-        time => 12,
-        vs_slowest => 13,
-      },
-      {
-        errors => 1.7e-05,
-        mod_overhead_time => 6.4,
-        participant => "Perl::Examples::Accessors::ClassAccessor",
-        samples => 21,
-        time => 12,
-        vs_slowest => 13,
-      },
-      {
-        errors => 1.5e-05,
-        mod_overhead_time => 6.4,
+        errors => 0.00025,
+        mod_overhead_time => 13.4,
         participant => "Perl::Examples::Accessors::ClassXSAccessor",
         samples => 20,
-        time => 12,
-        vs_slowest => 13,
+        time => 20,
+        vs_slowest => 10,
       },
       {
-        errors => 7.8e-06,
-        mod_overhead_time => 3.65,
-        participant => "Perl::Examples::Accessors::MojoBaseXS",
+        errors => 7.5e-05,
+        mod_overhead_time => 10.4,
+        participant => "Perl::Examples::Accessors::ClassStruct",
         samples => 20,
-        time => 9.25,
-        vs_slowest => 17.7,
+        time => 17,
+        vs_slowest => 14,
       },
       {
-        errors => 3.9e-05,
-        mod_overhead_time => 2.8,
+        errors => 8.2e-05,
+        mod_overhead_time => 9.4,
+        participant => "Perl::Examples::Accessors::ObjectSimple",
+        samples => 20,
+        time => 16,
+        vs_slowest => 15,
+      },
+      {
+        errors => 8e-05,
+        mod_overhead_time => 8.4,
+        participant => "Perl::Examples::Accessors::ObjectTinyRWXS",
+        samples => 20,
+        time => 15,
+        vs_slowest => 15,
+      },
+      {
+        errors => 1.6e-05,
+        mod_overhead_time => 8.4,
+        participant => "Perl::Examples::Accessors::ObjectTinyXS",
+        samples => 20,
+        time => 15,
+        vs_slowest => 16,
+      },
+      {
+        errors => 0.0004,
+        mod_overhead_time => 3.4,
         participant => "Perl::Examples::Accessors::SimpleAccessor",
-        samples => 20,
-        time => 8.4,
-        vs_slowest => 19,
-      },
-      {
-        errors => 1.9e-05,
-        mod_overhead_time => 2.5,
-        participant => "Perl::Examples::Accessors::Mo",
-        samples => 20,
-        time => 8.1,
+        samples => 21,
+        time => 10,
         vs_slowest => 20,
       },
       {
-        errors => 2.2e-05,
-        mod_overhead_time => 2.3,
-        participant => "Perl::Examples::Accessors::ClassAccessorArray",
+        errors => 0.00035,
+        mod_overhead_time => 3.4,
+        participant => "Perl::Examples::Accessors::ObjectTiny",
         samples => 21,
-        time => 7.9,
-        vs_slowest => 21,
+        time => 10,
+        vs_slowest => 20,
       },
       {
-        errors => 1.9e-05,
-        mod_overhead_time => 1.3,
-        participant => "Perl::Examples::Accessors::ObjectTiny",
-        samples => 22,
-        time => 6.9,
+        errors => 1.3e-05,
+        mod_overhead_time => 4.4,
+        participant => "Perl::Examples::Accessors::MojoBaseXS",
+        samples => 20,
+        time => 11,
+        vs_slowest => 22,
+      },
+      {
+        errors => 6.7e-05,
+        mod_overhead_time => 3.4,
+        participant => "Perl::Examples::Accessors::ClassAccessorArray",
+        samples => 20,
+        time => 10,
         vs_slowest => 24,
       },
       {
-        errors => 4.4e-05,
+        errors => 4.7e-05,
+        mod_overhead_time => 3.1,
+        participant => "Perl::Examples::Accessors::Mo",
+        samples => 20,
+        time => 9.7,
+        vs_slowest => 24,
+      },
+      {
+        errors => 0.0002,
+        mod_overhead_time => 2.4,
+        participant => "Perl::Examples::Accessors::Scalar",
+        samples => 20,
+        time => 9,
+        vs_slowest => 30,
+      },
+      {
+        errors => 1.4e-05,
         mod_overhead_time => 1.3,
         participant => "Perl::Examples::Accessors::ObjectTinyRW",
         samples => 20,
-        time => 6.9,
-        vs_slowest => 24,
+        time => 7.9,
+        vs_slowest => 30,
       },
       {
-        errors => 2.5e-05,
-        mod_overhead_time => 0.600000000000001,
-        participant => "Perl::Examples::Accessors::Scalar",
-        samples => 20,
-        time => 6.2,
-        vs_slowest => 26,
-      },
-      {
-        errors => 2.3e-05,
-        mod_overhead_time => 0.4,
+        errors => 3.5e-05,
+        mod_overhead_time => 0.9,
         participant => "Perl::Examples::Accessors::Array",
         samples => 20,
-        time => 6,
-        vs_slowest => 27,
+        time => 7.5,
+        vs_slowest => 32,
       },
       {
-        errors => 7.4e-06,
+        errors => 1.2e-05,
         mod_overhead_time => 0.4,
         participant => "Perl::Examples::Accessors::Hash",
         samples => 21,
-        time => 6,
-        vs_slowest => 27,
+        time => 7,
+        vs_slowest => 34,
       },
       {
-        errors => 1.7e-05,
+        errors => 1.3e-05,
         mod_overhead_time => 0,
         participant => "perl -e1 (baseline)",
         samples => 20,
-        time => 5.6,
-        vs_slowest => 29,
+        time => 6.6,
+        vs_slowest => 36,
       },
     ],
     {
@@ -336,7 +336,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2868.906,
+                                              speed                        => 2100.054,
                                               stepping                     => 4,
                                             },
                                             {
@@ -451,7 +451,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2848.179,
+                                              speed                        => 2200.023,
                                               stepping                     => 4,
                                             },
                                             {
@@ -566,7 +566,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2694.453,
+                                              speed                        => 2200.023,
                                               stepping                     => 4,
                                             },
                                             {
@@ -681,11 +681,11 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2884.656,
+                                              speed                        => 2199.968,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 16.2160120010376,
+      "func.elapsed_time"              => 23.0474898815155,
       "func.module_startup"            => 1,
       "func.module_versions"           => {
                                             "Bencher::Scenario::Accessors::ClassStartup" => undef,
@@ -713,31 +713,31 @@ our $results = [
                                             "Object::Tiny::RW::XS" => 0.03,
                                             "Object::Tiny::XS" => 1.01,
                                             "perl" => "v5.24.0",
-                                            "Perl::Examples::Accessors::Array" => 0.09,
-                                            "Perl::Examples::Accessors::ClassAccessor" => 0.09,
-                                            "Perl::Examples::Accessors::ClassAccessorArray" => 0.09,
-                                            "Perl::Examples::Accessors::ClassInsideOut" => 0.09,
-                                            "Perl::Examples::Accessors::ClassStruct" => 0.09,
-                                            "Perl::Examples::Accessors::ClassTiny" => 0.09,
-                                            "Perl::Examples::Accessors::ClassXSAccessor" => 0.09,
-                                            "Perl::Examples::Accessors::ClassXSAccessorArray" => 0.09,
-                                            "Perl::Examples::Accessors::EvoClass" => 0.09,
-                                            "Perl::Examples::Accessors::Hash" => 0.09,
-                                            "Perl::Examples::Accessors::Mo" => 0.09,
-                                            "Perl::Examples::Accessors::MojoBase" => 0.09,
-                                            "Perl::Examples::Accessors::MojoBaseXS" => 0.09,
-                                            "Perl::Examples::Accessors::Moo" => 0.09,
-                                            "Perl::Examples::Accessors::Moops" => 0.09,
-                                            "Perl::Examples::Accessors::Moos" => 0.09,
-                                            "Perl::Examples::Accessors::Moose" => 0.09,
-                                            "Perl::Examples::Accessors::Mouse" => 0.09,
-                                            "Perl::Examples::Accessors::ObjectSimple" => 0.09,
-                                            "Perl::Examples::Accessors::ObjectTiny" => 0.09,
-                                            "Perl::Examples::Accessors::ObjectTinyRW" => 0.09,
-                                            "Perl::Examples::Accessors::ObjectTinyRWXS" => 0.09,
-                                            "Perl::Examples::Accessors::ObjectTinyXS" => 0.09,
-                                            "Perl::Examples::Accessors::Scalar" => 0.09,
-                                            "Perl::Examples::Accessors::SimpleAccessor" => 0.09,
+                                            "Perl::Examples::Accessors::Array" => 0.11,
+                                            "Perl::Examples::Accessors::ClassAccessor" => 0.11,
+                                            "Perl::Examples::Accessors::ClassAccessorArray" => 0.11,
+                                            "Perl::Examples::Accessors::ClassInsideOut" => 0.11,
+                                            "Perl::Examples::Accessors::ClassStruct" => 0.11,
+                                            "Perl::Examples::Accessors::ClassTiny" => 0.11,
+                                            "Perl::Examples::Accessors::ClassXSAccessor" => 0.11,
+                                            "Perl::Examples::Accessors::ClassXSAccessorArray" => 0.11,
+                                            "Perl::Examples::Accessors::EvoClass" => 0.11,
+                                            "Perl::Examples::Accessors::Hash" => 0.11,
+                                            "Perl::Examples::Accessors::Mo" => 0.11,
+                                            "Perl::Examples::Accessors::MojoBase" => 0.11,
+                                            "Perl::Examples::Accessors::MojoBaseXS" => 0.11,
+                                            "Perl::Examples::Accessors::Moo" => 0.11,
+                                            "Perl::Examples::Accessors::Moops" => 0.11,
+                                            "Perl::Examples::Accessors::Moos" => 0.11,
+                                            "Perl::Examples::Accessors::Moose" => 0.11,
+                                            "Perl::Examples::Accessors::Mouse" => 0.11,
+                                            "Perl::Examples::Accessors::ObjectSimple" => 0.11,
+                                            "Perl::Examples::Accessors::ObjectTiny" => 0.11,
+                                            "Perl::Examples::Accessors::ObjectTinyRW" => 0.11,
+                                            "Perl::Examples::Accessors::ObjectTinyRWXS" => 0.11,
+                                            "Perl::Examples::Accessors::ObjectTinyXS" => 0.11,
+                                            "Perl::Examples::Accessors::Scalar" => 0.11,
+                                            "Perl::Examples::Accessors::SimpleAccessor" => 0.11,
                                             "Simple::Accessor" => 1.02,
                                             "Sys::Info" => 0.78,
                                           },
@@ -772,9 +772,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1473472033,
       "func.scenario_module_sha1sum"   => "9e49211383260a4cd180d04ca81586923477f8d6",
       "func.scenario_module_sha256sum" => "97f5aceb8e2616fe9259463dbd8ab2edba1558acd2dfec6bf44b04520ebf16f5",
-      "func.time_end"                  => 1480083411.05255,
+      "func.time_end"                  => 1480141027.24386,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1480083394.83653,
+      "func.time_start"                => 1480141004.19637,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "ms", "ms"],
       "table.fields"                   => [
