@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::Accessors::GeneratorStartup;
 
-our $VERSION = 0.12; # VERSION
+our $VERSION = 0.13; # VERSION
 
 our $results = [
   [
@@ -8,188 +8,188 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.00036,
-        mod_overhead_time => 144.3,
+        errors => 0.0008,
+        mod_overhead_time => 191,
         participant => "Moose",
         samples => 20,
-        time => 150,
+        time => 200,
         vs_slowest => 1,
       },
       {
-        errors => 6.9e-05,
-        mod_overhead_time => 60.3,
+        errors => 0.00019,
+        mod_overhead_time => 76,
         participant => "Moops",
         samples => 20,
-        time => 66,
-        vs_slowest => 2.2,
+        time => 85,
+        vs_slowest => 2.3,
       },
       {
-        errors => 0.0001,
-        mod_overhead_time => 30.3,
+        errors => 0.00019,
+        mod_overhead_time => 36,
         participant => "Evo::Class",
-        samples => 21,
-        time => 36,
-        vs_slowest => 4.1,
+        samples => 20,
+        time => 45,
+        vs_slowest => 4.3,
       },
       {
-        errors => 3.5e-05,
-        mod_overhead_time => 18.3,
+        errors => 0.00018,
+        mod_overhead_time => 23,
         participant => "Mouse",
         samples => 20,
-        time => 24,
+        time => 32,
         vs_slowest => 6.1,
       },
       {
-        errors => 6.3e-05,
-        mod_overhead_time => 14.3,
+        errors => 0.00058,
+        mod_overhead_time => 21,
+        participant => "Moo",
+        samples => 23,
+        time => 30,
+        vs_slowest => 7,
+      },
+      {
+        errors => 0.00023,
+        mod_overhead_time => 18,
         participant => "Moos",
         samples => 20,
-        time => 20,
+        time => 27,
         vs_slowest => 7.3,
       },
       {
-        errors => 4.4e-05,
-        mod_overhead_time => 14.3,
-        participant => "Moo",
-        samples => 20,
-        time => 20,
-        vs_slowest => 7.6,
-      },
-      {
-        errors => 2.8e-05,
-        mod_overhead_time => 10.3,
-        participant => "Class::InsideOut",
-        samples => 21,
-        time => 16,
-        vs_slowest => 9.2,
-      },
-      {
-        errors => 3.1e-05,
-        mod_overhead_time => 10.3,
+        errors => 0.00012,
+        mod_overhead_time => 13,
         participant => "Mojo::Base",
         samples => 20,
-        time => 16,
-        vs_slowest => 9.4,
+        time => 22,
+        vs_slowest => 8.8,
       },
       {
-        errors => 3.8e-05,
-        mod_overhead_time => 8.3,
-        participant => "Class::Tiny",
+        errors => 0.00033,
+        mod_overhead_time => 11,
+        participant => "Class::XSAccessor",
         samples => 20,
-        time => 14,
+        time => 20,
+        vs_slowest => 9,
+      },
+      {
+        errors => 0.00064,
+        mod_overhead_time => 11,
+        participant => "Object::Tiny::RW::XS",
+        samples => 22,
+        time => 20,
+        vs_slowest => 9,
+      },
+      {
+        errors => 0.00085,
+        mod_overhead_time => 11,
+        participant => "Object::Tiny::XS",
+        samples => 20,
+        time => 20,
+        vs_slowest => 9,
+      },
+      {
+        errors => 3.7e-05,
+        mod_overhead_time => 11,
+        participant => "Class::InsideOut",
+        samples => 22,
+        time => 20,
+        vs_slowest => 9.8,
+      },
+      {
+        errors => 0.00026,
+        mod_overhead_time => 11,
+        participant => "Class::XSAccessor::Array",
+        samples => 20,
+        time => 20,
         vs_slowest => 10,
       },
       {
-        errors => 3.2e-05,
-        mod_overhead_time => 7.3,
-        participant => "Class::Struct",
-        samples => 21,
-        time => 13,
+        errors => 3.3e-05,
+        mod_overhead_time => 8,
+        participant => "Class::Tiny",
+        samples => 20,
+        time => 17,
         vs_slowest => 11,
       },
       {
-        errors => 4.3e-05,
-        mod_overhead_time => 7.3,
-        participant => "Class::XSAccessor::Array",
-        samples => 21,
-        time => 13,
-        vs_slowest => 12,
-      },
-      {
-        errors => 3.8e-05,
-        mod_overhead_time => 7.3,
-        participant => "Object::Tiny::RW::XS",
+        errors => 3e-05,
+        mod_overhead_time => 6,
+        participant => "Class::Struct",
         samples => 20,
-        time => 13,
-        vs_slowest => 12,
+        time => 15,
+        vs_slowest => 13,
       },
       {
-        errors => 1.5e-05,
-        mod_overhead_time => 7.3,
-        participant => "Object::Simple",
-        samples => 21,
-        time => 13,
-        vs_slowest => 12,
-      },
-      {
-        errors => 4.6e-05,
-        mod_overhead_time => 7.3,
-        participant => "Object::Tiny::XS",
-        samples => 21,
-        time => 13,
-        vs_slowest => 12,
-      },
-      {
-        errors => 3.4e-05,
-        mod_overhead_time => 6.3,
+        errors => 4.5e-05,
+        mod_overhead_time => 6,
         participant => "Class::Accessor",
         samples => 20,
-        time => 12,
-        vs_slowest => 12,
+        time => 15,
+        vs_slowest => 13,
       },
       {
-        errors => 2e-05,
-        mod_overhead_time => 6.3,
-        participant => "Class::XSAccessor",
+        errors => 1.3e-05,
+        mod_overhead_time => 5.9,
+        participant => "Object::Simple",
         samples => 20,
-        time => 12,
-        vs_slowest => 12,
+        time => 14.9,
+        vs_slowest => 13.1,
       },
       {
-        errors => 5.3e-05,
-        mod_overhead_time => 3.8,
+        errors => 9.9e-05,
+        mod_overhead_time => 3,
         participant => "Mojo::Base::XS",
         samples => 20,
-        time => 9.5,
+        time => 12,
         vs_slowest => 16,
       },
       {
-        errors => 1.7e-05,
-        mod_overhead_time => 2.9,
+        errors => 3.1e-05,
+        mod_overhead_time => 1,
         participant => "Simple::Accessor",
         samples => 20,
-        time => 8.6,
-        vs_slowest => 17,
-      },
-      {
-        errors => 3.2e-05,
-        mod_overhead_time => 2.2,
-        participant => "Class::Accessor::Array",
-        samples => 20,
-        time => 7.9,
+        time => 10,
         vs_slowest => 19,
       },
-      {
-        errors => 1.1e-05,
-        mod_overhead_time => 2.2,
-        participant => "Mo",
-        samples => 20,
-        time => 7.9,
-        vs_slowest => 19,
-      },
-      {
-        errors => 3.5e-05,
-        mod_overhead_time => 1.2,
-        participant => "Object::Tiny",
-        samples => 23,
-        time => 6.9,
-        vs_slowest => 21,
-      },
       {
         errors => 2.1e-05,
-        mod_overhead_time => 1.1,
-        participant => "Object::Tiny::RW",
+        mod_overhead_time => 0.699999999999999,
+        participant => "Class::Accessor::Array",
         samples => 20,
-        time => 6.8,
-        vs_slowest => 22,
+        time => 9.7,
+        vs_slowest => 20,
       },
       {
-        errors => 1.7e-05,
+        errors => 2.1e-05,
+        mod_overhead_time => 0.300000000000001,
+        participant => "Mo",
+        samples => 21,
+        time => 9.3,
+        vs_slowest => 21,
+      },
+      {
+        errors => 0.00016,
         mod_overhead_time => 0,
         participant => "perl -e1 (baseline)",
+        samples => 22,
+        time => 9,
+        vs_slowest => 20,
+      },
+      {
+        errors => 3.1e-05,
+        mod_overhead_time => -1,
+        participant => "Object::Tiny::RW",
         samples => 20,
-        time => 5.7,
-        vs_slowest => 26,
+        time => 8,
+        vs_slowest => 24,
+      },
+      {
+        errors => 9.1e-06,
+        mod_overhead_time => -1.1,
+        participant => "Object::Tiny",
+        samples => 20,
+        time => 7.9,
+        vs_slowest => 25,
       },
     ],
     {
@@ -312,7 +312,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2698.992,
+                                              speed                        => 1799.984,
                                               stepping                     => 4,
                                             },
                                             {
@@ -427,7 +427,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2725.898,
+                                              speed                        => 1800.093,
                                               stepping                     => 4,
                                             },
                                             {
@@ -542,7 +542,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => "2748.210",
+                                              speed                        => 1799.984,
                                               stepping                     => 4,
                                             },
                                             {
@@ -657,11 +657,11 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2611.273,
+                                              speed                        => 1799.984,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 12.1655628681183,
+      "func.elapsed_time"              => 18.1830599308014,
       "func.module_startup"            => 1,
       "func.module_versions"           => {
                                             "Bencher::Scenario::Accessors::GeneratorStartup" => undef,
@@ -723,9 +723,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1459169292,
       "func.scenario_module_sha1sum"   => "8ca3e295d90cab65e0de29ab5e887d7eb667bf8d",
       "func.scenario_module_sha256sum" => "ae94f28e6695e34d05c797d499629801c18c6d478feb5058fb4270ecf4c81ddb",
-      "func.time_end"                  => 1480083424.73752,
+      "func.time_end"                  => 1480141047.39788,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1480083412.57195,
+      "func.time_start"                => 1480141029.21482,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "ms", "ms"],
       "table.fields"                   => [
