@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::Accessors::Get;
 
-our $VERSION = 0.12; # VERSION
+our $VERSION = 0.13; # VERSION
 
 our $results = [
   [
@@ -8,212 +8,212 @@ our $results = [
     "OK",
     [
       {
-        errors => 2.1e-10,
+        errors => 4.3e-10,
         participant => "Class::Accessor",
-        rate => 2230000,
-        samples => 20,
-        time => 449,
+        rate => 1970000,
+        samples => 26,
+        time => 507,
         vs_slowest => 1,
       },
       {
-        errors => 0,
-        participant => "Simple::Accessor",
-        rate => 3225550,
-        samples => 22,
-        time => 310.025,
-        vs_slowest => 1.44806,
-      },
-      {
-        errors => 3.1e-10,
+        errors => 3.7e-09,
         participant => "Class::InsideOut",
-        rate => 3300000,
+        rate => 2400000,
         samples => 20,
-        time => 310,
-        vs_slowest => 1.5,
+        time => 410,
+        vs_slowest => 1.2,
       },
       {
-        errors => 1e-10,
-        participant => "Class::Struct",
-        rate => 4860000,
-        samples => 20,
-        time => 206,
-        vs_slowest => 2.18,
+        errors => 4.3e-10,
+        participant => "Simple::Accessor",
+        rate => 2600000,
+        samples => 24,
+        time => 380,
+        vs_slowest => 1.3,
       },
       {
-        errors => 1e-10,
+        errors => 2.6e-09,
         participant => "Evo::Class",
-        rate => 5380000,
+        rate => 3800000,
         samples => 20,
-        time => 186,
-        vs_slowest => 2.41,
+        time => 260,
+        vs_slowest => 1.9,
       },
       {
-        errors => 3.6e-10,
-        participant => "Mojo::Base",
-        rate => 5500000,
-        samples => 27,
-        time => 180,
-        vs_slowest => 2.5,
-      },
-      {
-        errors => 0,
-        participant => "Mo",
-        rate => 5577880,
+        errors => 1.1e-10,
+        participant => "Class::Struct",
+        rate => 4080000,
         samples => 20,
-        time => 179.28,
-        vs_slowest => 2.50409,
-      },
-      {
-        errors => 0,
-        participant => "no generator (hash-based)",
-        rate => 5865090,
-        samples => 34,
-        time => 170.501,
-        vs_slowest => 2.63303,
-      },
-      {
-        errors => 0,
-        participant => "Class::Tiny",
-        rate => 6192400,
-        samples => 20,
-        time => 161.488,
-        vs_slowest => 2.77997,
-      },
-      {
-        errors => 1e-10,
-        participant => "no generator (array-based)",
-        rate => 6480000,
-        samples => 20,
-        time => 154,
-        vs_slowest => 2.91,
-      },
-      {
-        errors => 0,
-        participant => "Object::Simple",
-        rate => 6505480,
-        samples => 20,
-        time => 153.717,
-        vs_slowest => 2.92052,
-      },
-      {
-        errors => 0,
-        participant => "Moose",
-        rate => 6548450,
-        samples => 32,
-        time => 152.708,
-        vs_slowest => 2.93982,
+        time => 245,
+        vs_slowest => 2.07,
       },
       {
         errors => 0,
         participant => "Object::Tiny::RW",
-        rate => 6585450,
-        samples => 21,
-        time => 151.85,
-        vs_slowest => 2.95643,
-      },
-      {
-        errors => 0,
-        participant => "Class::Accessor::Array",
-        rate => 6849920,
+        rate => 4588390,
         samples => 20,
-        time => 145.987,
-        vs_slowest => 3.07516,
+        time => 217.941,
+        vs_slowest => 2.32703,
       },
       {
-        errors => 5.1e-11,
-        participant => "Object::Tiny",
-        rate => 7750000,
-        samples => 21,
-        time => 129,
-        vs_slowest => 3.48,
-      },
-      {
-        errors => 2.1e-10,
-        participant => "Mouse",
-        rate => 11000000,
+        errors => 1.1e-11,
+        participant => "no generator (hash-based)",
+        rate => 4611000,
         samples => 20,
-        time => 94,
-        vs_slowest => 4.8,
+        time => 216.9,
+        vs_slowest => 2.339,
       },
       {
-        errors => 5.1e-11,
-        participant => "Moos",
-        rate => 12300000,
-        samples => 21,
-        time => 81.2,
-        vs_slowest => 5.53,
-      },
-      {
-        errors => 2.1e-10,
-        participant => "Object::Tiny::XS",
-        rate => 14000000,
-        samples => 20,
-        time => 73,
-        vs_slowest => 6.1,
-      },
-      {
-        errors => 2.6e-10,
-        participant => "Object::Tiny::RW::XS",
-        rate => 14000000,
-        samples => 20,
-        time => 72,
-        vs_slowest => 6.2,
-      },
-      {
-        errors => 1.9e-10,
-        participant => "Class::XSAccessor",
-        rate => 14000000,
+        errors => 3.1e-10,
+        participant => "Mo",
+        rate => 4600000,
         samples => 23,
-        time => 71,
-        vs_slowest => 6.4,
+        time => 220,
+        vs_slowest => 2.3,
       },
       {
-        errors => 2e-10,
-        participant => "Mojo::Base::XS",
-        rate => 14000000,
-        samples => 22,
-        time => 70,
-        vs_slowest => 6.4,
-      },
-      {
-        errors => 1.6e-10,
-        participant => "Moops",
-        rate => 15000000,
+        errors => 1.1e-11,
+        participant => "Class::Tiny",
+        rate => 4897000,
         samples => 20,
-        time => 67,
-        vs_slowest => 6.7,
-      },
-      {
-        errors => 0,
-        participant => "Moo",
-        rate => 15136400,
-        samples => 20,
-        time => 66.0657,
-        vs_slowest => 6.79525,
-      },
-      {
-        errors => 0,
-        participant => "Class::XSAccessor::Array",
-        rate => 16309000,
-        samples => 20,
-        time => 61.316,
-        vs_slowest => 7.32164,
+        time => 204.2,
+        vs_slowest => 2.484,
       },
       {
         errors => 1e-10,
-        participant => "raw hash access",
-        rate => 27000000,
+        participant => "Object::Simple",
+        rate => 5090000,
         samples => 20,
-        time => 37,
-        vs_slowest => 12,
+        time => 196,
+        vs_slowest => 2.58,
       },
       {
-        errors => 2.6e-11,
-        participant => "raw array access",
-        rate => 30900000,
+        errors => 2.7e-09,
+        participant => "Mojo::Base",
+        rate => 7000000,
         samples => 20,
-        time => 32.3,
-        vs_slowest => 13.9,
+        time => 200,
+        vs_slowest => 3,
+      },
+      {
+        errors => 2.3e-10,
+        participant => "Object::Tiny",
+        rate => 7100000,
+        samples => 20,
+        time => 140,
+        vs_slowest => 3.6,
+      },
+      {
+        errors => 2.7e-09,
+        participant => "no generator (array-based)",
+        rate => 8000000,
+        samples => 20,
+        time => 100,
+        vs_slowest => 4,
+      },
+      {
+        errors => 8.3e-10,
+        participant => "Class::XSAccessor",
+        rate => 9000000,
+        samples => 20,
+        time => 110,
+        vs_slowest => 4.5,
+      },
+      {
+        errors => 4.4e-10,
+        participant => "Mojo::Base::XS",
+        rate => 9100000,
+        samples => 24,
+        time => 110,
+        vs_slowest => 4.6,
+      },
+      {
+        errors => 1e-09,
+        participant => "Moo",
+        rate => 9600000,
+        samples => 23,
+        time => 100,
+        vs_slowest => 4.9,
+      },
+      {
+        errors => 3.1e-10,
+        participant => "Mouse",
+        rate => 11000000,
+        samples => 30,
+        time => 94,
+        vs_slowest => 5.4,
+      },
+      {
+        errors => 2.4e-10,
+        participant => "Object::Tiny::RW::XS",
+        rate => 12000000,
+        samples => 20,
+        time => 86,
+        vs_slowest => 5.9,
+      },
+      {
+        errors => 8.9e-10,
+        participant => "Class::XSAccessor::Array",
+        rate => 10000000,
+        samples => 20,
+        time => 80,
+        vs_slowest => 6,
+      },
+      {
+        errors => 2.9e-10,
+        participant => "Object::Tiny::XS",
+        rate => 13000000,
+        samples => 20,
+        time => 79,
+        vs_slowest => 6.4,
+      },
+      {
+        errors => 7.4e-10,
+        participant => "Moose",
+        rate => 13000000,
+        samples => 20,
+        time => 79,
+        vs_slowest => 6.5,
+      },
+      {
+        errors => 2.6e-10,
+        participant => "Moops",
+        rate => 13000000,
+        samples => 20,
+        time => 78,
+        vs_slowest => 6.5,
+      },
+      {
+        errors => 9.5e-10,
+        participant => "Class::Accessor::Array",
+        rate => 10000000,
+        samples => 20,
+        time => 80,
+        vs_slowest => 7,
+      },
+      {
+        errors => 1.7e-10,
+        participant => "raw hash access",
+        rate => 21000000,
+        samples => 29,
+        time => 49,
+        vs_slowest => 10,
+      },
+      {
+        errors => 0,
+        participant => "raw array access",
+        rate => 30791900,
+        samples => 20,
+        time => 32.4761,
+        vs_slowest => 15.6163,
+      },
+      {
+        errors => 8.5e-10,
+        participant => "Moos",
+        rate => -70000000,
+        samples => 20,
+        time => -10,
+        vs_slowest => -40,
       },
     ],
     {
@@ -336,7 +336,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2760.515,
+                                              speed                        => 1852.921,
                                               stepping                     => 4,
                                             },
                                             {
@@ -451,7 +451,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => "2769.320",
+                                              speed                        => 1884.914,
                                               stepping                     => 4,
                                             },
                                             {
@@ -566,7 +566,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2616.414,
+                                              speed                        => 1899.953,
                                               stepping                     => 4,
                                             },
                                             {
@@ -681,11 +681,11 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2874.976,
+                                              speed                        => "1888.960",
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.734180212020874,
+      "func.elapsed_time"              => 0.760756015777588,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "Bencher::Scenario::Accessors::Get" => undef,
@@ -713,30 +713,30 @@ our $results = [
                                             "Object::Tiny::RW::XS" => 0.03,
                                             "Object::Tiny::XS" => 1.01,
                                             "perl" => "v5.24.0",
-                                            "Perl::Examples::Accessors::Array" => 0.09,
-                                            "Perl::Examples::Accessors::ClassAccessor" => 0.09,
-                                            "Perl::Examples::Accessors::ClassAccessorArray" => 0.09,
-                                            "Perl::Examples::Accessors::ClassInsideOut" => 0.09,
-                                            "Perl::Examples::Accessors::ClassStruct" => 0.09,
-                                            "Perl::Examples::Accessors::ClassTiny" => 0.09,
-                                            "Perl::Examples::Accessors::ClassXSAccessor" => 0.09,
-                                            "Perl::Examples::Accessors::ClassXSAccessorArray" => 0.09,
-                                            "Perl::Examples::Accessors::EvoClass" => 0.09,
-                                            "Perl::Examples::Accessors::Hash" => 0.09,
-                                            "Perl::Examples::Accessors::Mo" => 0.09,
-                                            "Perl::Examples::Accessors::MojoBase" => 0.09,
-                                            "Perl::Examples::Accessors::MojoBaseXS" => 0.09,
-                                            "Perl::Examples::Accessors::Moo" => 0.09,
-                                            "Perl::Examples::Accessors::Moops" => 0.09,
-                                            "Perl::Examples::Accessors::Moos" => 0.09,
-                                            "Perl::Examples::Accessors::Moose" => 0.09,
-                                            "Perl::Examples::Accessors::Mouse" => 0.09,
-                                            "Perl::Examples::Accessors::ObjectSimple" => 0.09,
-                                            "Perl::Examples::Accessors::ObjectTiny" => 0.09,
-                                            "Perl::Examples::Accessors::ObjectTinyRW" => 0.09,
-                                            "Perl::Examples::Accessors::ObjectTinyRWXS" => 0.09,
-                                            "Perl::Examples::Accessors::ObjectTinyXS" => 0.09,
-                                            "Perl::Examples::Accessors::SimpleAccessor" => 0.09,
+                                            "Perl::Examples::Accessors::Array" => 0.11,
+                                            "Perl::Examples::Accessors::ClassAccessor" => 0.11,
+                                            "Perl::Examples::Accessors::ClassAccessorArray" => 0.11,
+                                            "Perl::Examples::Accessors::ClassInsideOut" => 0.11,
+                                            "Perl::Examples::Accessors::ClassStruct" => 0.11,
+                                            "Perl::Examples::Accessors::ClassTiny" => 0.11,
+                                            "Perl::Examples::Accessors::ClassXSAccessor" => 0.11,
+                                            "Perl::Examples::Accessors::ClassXSAccessorArray" => 0.11,
+                                            "Perl::Examples::Accessors::EvoClass" => 0.11,
+                                            "Perl::Examples::Accessors::Hash" => 0.11,
+                                            "Perl::Examples::Accessors::Mo" => 0.11,
+                                            "Perl::Examples::Accessors::MojoBase" => 0.11,
+                                            "Perl::Examples::Accessors::MojoBaseXS" => 0.11,
+                                            "Perl::Examples::Accessors::Moo" => 0.11,
+                                            "Perl::Examples::Accessors::Moops" => 0.11,
+                                            "Perl::Examples::Accessors::Moos" => 0.11,
+                                            "Perl::Examples::Accessors::Moose" => 0.11,
+                                            "Perl::Examples::Accessors::Mouse" => 0.11,
+                                            "Perl::Examples::Accessors::ObjectSimple" => 0.11,
+                                            "Perl::Examples::Accessors::ObjectTiny" => 0.11,
+                                            "Perl::Examples::Accessors::ObjectTinyRW" => 0.11,
+                                            "Perl::Examples::Accessors::ObjectTinyRWXS" => 0.11,
+                                            "Perl::Examples::Accessors::ObjectTinyXS" => 0.11,
+                                            "Perl::Examples::Accessors::SimpleAccessor" => 0.11,
                                             "Simple::Accessor" => 1.02,
                                             "Sys::Info" => 0.78,
                                           },
@@ -768,12 +768,12 @@ our $results = [
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::Accessors::Get",
       "func.scenario_module_md5sum"    => "b8c97c69088ac24b48d3b0ebdd733de2",
-      "func.scenario_module_mtime"     => 1480055471,
+      "func.scenario_module_mtime"     => 1480140843,
       "func.scenario_module_sha1sum"   => "0041085ad18b13f697b5c45fcaf6b63db5224ecf",
       "func.scenario_module_sha256sum" => "a4c8ae55843097cf2f1e87f32abec3865d39262c08b02468601d96d8a5894d6a",
-      "func.time_end"                  => 1480083425.65925,
+      "func.time_end"                  => 1480141048.45846,
       "func.time_factor"               => 1000000000,
-      "func.time_start"                => 1480083424.92507,
+      "func.time_start"                => 1480141047.69771,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ns"],
       "table.fields"                   => [
