@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::Accessors::Set;
 
-our $VERSION = 0.12; # VERSION
+our $VERSION = 0.13; # VERSION
 
 our $results = [
   [
@@ -8,196 +8,196 @@ our $results = [
     "OK",
     [
       {
-        errors => 1.4e-09,
+        errors => 1.7e-09,
         participant => "Simple::Accessor",
-        rate => 259000,
-        samples => 28,
-        time => 3.86,
+        rate => 198000,
+        samples => 20,
+        time => 5.04,
         vs_slowest => 1,
       },
       {
-        errors => 0,
+        errors => 3.9e-10,
         participant => "Class::Accessor",
-        rate => 1918800,
-        samples => 22,
-        time => 0.52116,
-        vs_slowest => 7.40018,
+        rate => 1600000,
+        samples => 20,
+        time => 0.627,
+        vs_slowest => 8.04,
       },
       {
-        errors => 0,
+        errors => 2.1e-10,
         participant => "Class::InsideOut",
-        rate => 2499980,
+        rate => 1970000,
         samples => 20,
-        time => 0.400003,
-        vs_slowest => 9.64161,
+        time => 0.507,
+        vs_slowest => 9.93,
       },
       {
-        errors => 4.2e-10,
+        errors => 1.7e-10,
+        participant => "Object::Tiny::RW",
+        rate => 2970000,
+        samples => 32,
+        time => 0.337,
+        vs_slowest => 15,
+      },
+      {
+        errors => 8.5e-10,
         participant => "Evo::Class",
-        rate => 4500000,
+        rate => 3200000,
         samples => 20,
-        time => 0.22,
-        vs_slowest => 17,
+        time => 0.31,
+        vs_slowest => 16,
       },
       {
-        errors => 4.2e-10,
+        errors => 8.2e-10,
         participant => "Class::Struct",
-        rate => 4500000,
-        samples => 20,
-        time => 0.22,
-        vs_slowest => 17,
+        rate => 3200000,
+        samples => 21,
+        time => 0.31,
+        vs_slowest => 16,
       },
       {
         errors => 4.2e-10,
         participant => "Class::Tiny",
-        rate => 4600000,
+        rate => 3400000,
         samples => 20,
-        time => 0.22,
-        vs_slowest => 18,
+        time => 0.29,
+        vs_slowest => 17,
       },
       {
-        errors => 3.1e-10,
-        participant => "Object::Tiny::RW",
-        rate => 4600000,
-        samples => 20,
-        time => 0.22,
-        vs_slowest => 18,
-      },
-      {
-        errors => 9.1e-11,
-        participant => "Mojo::Base",
-        rate => 4650000,
-        samples => 26,
-        time => 0.215,
-        vs_slowest => 18,
-      },
-      {
-        errors => 4.1e-10,
+        errors => 2.1e-10,
         participant => "Moose",
-        rate => 4700000,
-        samples => 21,
+        rate => 3440000,
+        samples => 23,
+        time => 0.291,
+        vs_slowest => 17.3,
+      },
+      {
+        errors => 1.1e-10,
+        participant => "Mojo::Base",
+        rate => 3550000,
+        samples => 20,
+        time => 0.282,
+        vs_slowest => 17.9,
+      },
+      {
+        errors => 5.1e-10,
+        participant => "Object::Simple",
+        rate => 4200000,
+        samples => 20,
+        time => 0.24,
+        vs_slowest => 21,
+      },
+      {
+        errors => 3.5e-10,
+        participant => "no generator (array-based)",
+        rate => 4500000,
+        samples => 23,
+        time => 0.22,
+        vs_slowest => 23,
+      },
+      {
+        errors => 4.3e-10,
+        participant => "no generator (hash-based)",
+        rate => 4600000,
+        samples => 20,
+        time => 0.22,
+        vs_slowest => 23,
+      },
+      {
+        errors => 4.8e-10,
+        participant => "Mo",
+        rate => 4800000,
+        samples => 29,
         time => 0.21,
-        vs_slowest => 18,
+        vs_slowest => 24,
+      },
+      {
+        errors => 4.4e-10,
+        participant => "Class::Accessor::Array",
+        rate => 5400000,
+        samples => 20,
+        time => 0.18,
+        vs_slowest => 27,
       },
       {
         errors => 4.2e-10,
-        participant => "Mo",
-        rate => 4800000,
+        participant => "Mojo::Base::XS",
+        rate => 6600000,
         samples => 20,
-        time => 0.21,
-        vs_slowest => 18,
+        time => 0.15,
+        vs_slowest => 33,
       },
       {
         errors => 0,
-        participant => "Class::Accessor::Array",
-        rate => 4922840,
-        samples => 20,
-        time => 0.203135,
-        vs_slowest => 18.9858,
-      },
-      {
-        errors => 0,
-        participant => "Object::Simple",
-        rate => 5285030,
-        samples => 21,
-        time => 0.189214,
-        vs_slowest => 20.3826,
-      },
-      {
-        errors => 1e-10,
-        participant => "no generator (hash-based)",
-        rate => 5420000,
-        samples => 20,
-        time => 0.185,
-        vs_slowest => 20.9,
-      },
-      {
-        errors => 0,
-        participant => "no generator (array-based)",
-        rate => 6113640,
-        samples => 23,
-        time => 0.163569,
-        vs_slowest => 23.5783,
-      },
-      {
-        errors => 2.1e-10,
-        participant => "Mouse",
-        rate => 9500000,
-        samples => 20,
-        time => 0.1,
-        vs_slowest => 37,
-      },
-      {
-        errors => 0,
-        participant => "Class::XSAccessor",
-        rate => 10297200,
-        samples => 20,
-        time => 0.0971137,
-        vs_slowest => 39.713,
-      },
-      {
-        errors => 2.6e-10,
         participant => "Moos",
-        rate => 10000000,
+        rate => 6772030,
         samples => 20,
-        time => 0.096,
+        time => 0.147666,
+        vs_slowest => 34.135,
+      },
+      {
+        errors => 3.1e-10,
+        participant => "Class::XSAccessor",
+        rate => 7100000,
+        samples => 20,
+        time => 0.14,
+        vs_slowest => 36,
+      },
+      {
+        errors => 2.3e-10,
+        participant => "Moo",
+        rate => 8000000,
+        samples => 25,
+        time => 0.13,
         vs_slowest => 40,
       },
       {
-        errors => 2.1e-10,
+        errors => 3.5e-11,
         participant => "Object::Tiny::RW::XS",
-        rate => 11000000,
+        rate => 8330000,
         samples => 20,
-        time => 0.091,
-        vs_slowest => 43,
+        time => 0.12,
+        vs_slowest => 42,
       },
       {
-        errors => 2.1e-10,
-        participant => "Mojo::Base::XS",
-        rate => 11000000,
-        samples => 20,
-        time => 0.09,
-        vs_slowest => 43,
-      },
-      {
-        errors => 4.4e-11,
+        errors => 1.2e-11,
         participant => "Moops",
-        rate => 11500000,
-        samples => 28,
-        time => 0.0868,
-        vs_slowest => 44.4,
-      },
-      {
-        errors => 5.2e-11,
-        participant => "Moo",
-        rate => 11500000,
+        rate => 8629000,
         samples => 20,
-        time => 0.0866,
-        vs_slowest => 44.5,
+        time => 0.1159,
+        vs_slowest => 43.49,
       },
       {
-        errors => 0,
+        errors => 1.7e-10,
         participant => "Class::XSAccessor::Array",
-        rate => 13172700,
+        rate => 8800000,
         samples => 20,
-        time => 0.0759144,
-        vs_slowest => 50.8029,
+        time => 0.11,
+        vs_slowest => 44,
       },
       {
-        errors => 2.1e-10,
+        errors => 7.3e-10,
+        participant => "Mouse",
+        rate => 10000000,
+        samples => 20,
+        time => 0.07,
+        vs_slowest => 70,
+      },
+      {
+        errors => 1.1e-10,
         participant => "raw hash access",
-        rate => 20000000,
+        rate => 15000000,
         samples => 20,
-        time => 0.05,
-        vs_slowest => 77,
+        time => 0.067,
+        vs_slowest => 75,
       },
       {
-        errors => 0,
+        errors => 1.1e-10,
         participant => "raw array access",
-        rate => 22052400,
-        samples => 21,
-        time => 0.0453465,
-        vs_slowest => 85.0489,
+        rate => 18000000,
+        samples => 20,
+        time => 0.056,
+        vs_slowest => 91,
       },
     ],
     {
@@ -320,7 +320,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2883.726,
+                                              speed                        => "2085.890",
                                               stepping                     => 4,
                                             },
                                             {
@@ -435,7 +435,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2750.945,
+                                              speed                        => 2060.789,
                                               stepping                     => 4,
                                             },
                                             {
@@ -550,7 +550,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2891.984,
+                                              speed                        => 2026.171,
                                               stepping                     => 4,
                                             },
                                             {
@@ -665,11 +665,11 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2897.835,
+                                              speed                        => 2061.335,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.648809909820557,
+      "func.elapsed_time"              => 0.698377132415771,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "Bencher::Scenario::Accessors::Set" => undef,
@@ -697,28 +697,28 @@ our $results = [
                                             "Object::Tiny::RW::XS" => 0.03,
                                             "Object::Tiny::XS" => 1.01,
                                             "perl" => "v5.24.0",
-                                            "Perl::Examples::Accessors::Array" => 0.09,
-                                            "Perl::Examples::Accessors::ClassAccessor" => 0.09,
-                                            "Perl::Examples::Accessors::ClassAccessorArray" => 0.09,
-                                            "Perl::Examples::Accessors::ClassInsideOut" => 0.09,
-                                            "Perl::Examples::Accessors::ClassStruct" => 0.09,
-                                            "Perl::Examples::Accessors::ClassTiny" => 0.09,
-                                            "Perl::Examples::Accessors::ClassXSAccessor" => 0.09,
-                                            "Perl::Examples::Accessors::ClassXSAccessorArray" => 0.09,
-                                            "Perl::Examples::Accessors::EvoClass" => 0.09,
-                                            "Perl::Examples::Accessors::Hash" => 0.09,
-                                            "Perl::Examples::Accessors::Mo" => 0.09,
-                                            "Perl::Examples::Accessors::MojoBase" => 0.09,
-                                            "Perl::Examples::Accessors::MojoBaseXS" => 0.09,
-                                            "Perl::Examples::Accessors::Moo" => 0.09,
-                                            "Perl::Examples::Accessors::Moops" => 0.09,
-                                            "Perl::Examples::Accessors::Moos" => 0.09,
-                                            "Perl::Examples::Accessors::Moose" => 0.09,
-                                            "Perl::Examples::Accessors::Mouse" => 0.09,
-                                            "Perl::Examples::Accessors::ObjectSimple" => 0.09,
-                                            "Perl::Examples::Accessors::ObjectTinyRW" => 0.09,
-                                            "Perl::Examples::Accessors::ObjectTinyRWXS" => 0.09,
-                                            "Perl::Examples::Accessors::SimpleAccessor" => 0.09,
+                                            "Perl::Examples::Accessors::Array" => 0.11,
+                                            "Perl::Examples::Accessors::ClassAccessor" => 0.11,
+                                            "Perl::Examples::Accessors::ClassAccessorArray" => 0.11,
+                                            "Perl::Examples::Accessors::ClassInsideOut" => 0.11,
+                                            "Perl::Examples::Accessors::ClassStruct" => 0.11,
+                                            "Perl::Examples::Accessors::ClassTiny" => 0.11,
+                                            "Perl::Examples::Accessors::ClassXSAccessor" => 0.11,
+                                            "Perl::Examples::Accessors::ClassXSAccessorArray" => 0.11,
+                                            "Perl::Examples::Accessors::EvoClass" => 0.11,
+                                            "Perl::Examples::Accessors::Hash" => 0.11,
+                                            "Perl::Examples::Accessors::Mo" => 0.11,
+                                            "Perl::Examples::Accessors::MojoBase" => 0.11,
+                                            "Perl::Examples::Accessors::MojoBaseXS" => 0.11,
+                                            "Perl::Examples::Accessors::Moo" => 0.11,
+                                            "Perl::Examples::Accessors::Moops" => 0.11,
+                                            "Perl::Examples::Accessors::Moos" => 0.11,
+                                            "Perl::Examples::Accessors::Moose" => 0.11,
+                                            "Perl::Examples::Accessors::Mouse" => 0.11,
+                                            "Perl::Examples::Accessors::ObjectSimple" => 0.11,
+                                            "Perl::Examples::Accessors::ObjectTinyRW" => 0.11,
+                                            "Perl::Examples::Accessors::ObjectTinyRWXS" => 0.11,
+                                            "Perl::Examples::Accessors::SimpleAccessor" => 0.11,
                                             "Simple::Accessor" => 1.02,
                                             "Sys::Info" => 0.78,
                                           },
@@ -753,9 +753,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1480075844,
       "func.scenario_module_sha1sum"   => "04b532534e4dbeb4059ed136136014e705973784",
       "func.scenario_module_sha256sum" => "57e2384e577a0864ee7a5b36cca5e886c5eb6b028245a2cd7b80d5b8e26b1ab6",
-      "func.time_end"                  => 1480083426.49854,
+      "func.time_end"                  => 1480141049.45434,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1480083425.84973,
+      "func.time_start"                => 1480141048.75596,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "\x{3BC}s"],
       "table.fields"                   => [
